@@ -1,9 +1,9 @@
 /*
  * fonts.c
- * libansilove 1.3.1
+ * libansilove 1.4.1
  * https://www.ansilove.org
  *
- * Copyright (c) 2011-2022 Stefan Vogt, Brian Cassidy, and Frederic Cambus
+ * Copyright (c) 2011-2023 Stefan Vogt, Brian Cassidy, and Frederic Cambus
  * All rights reserved.
  *
  * libansilove is licensed under the BSD 2-Clause license.
@@ -29,6 +29,7 @@
 #include "fonts/font_pc_nordic.h"
 #include "fonts/font_pc_portuguese.h"
 #include "fonts/font_pc_russian.h"
+#include "fonts/font_pc_spleen.h"
 #include "fonts/font_pc_terminus.h"
 #include "fonts/font_pc_turkish.h"
 #include "fonts/font_amiga_microknight.h"
@@ -114,6 +115,11 @@ select_font(struct fontStruct *fontData, int font)
 		fontData->width = 9;
 		fontData->height = 16;
 		break;
+	case ANSILOVE_FONT_SPLEEN:
+		fontData->font_data = font_pc_spleen;
+		fontData->width = 9;
+		fontData->height = 16;
+		break;
 	case ANSILOVE_FONT_TERMINUS:
 		fontData->font_data = font_pc_terminus;
 		fontData->width = 9;
